summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSteve Lin <stlin@nvidia.com>2010-06-14 13:44:40 -0700
committerGary King <gking@nvidia.com>2010-06-14 13:56:21 -0700
commit8369e2d12ec199ecadf8312520868b183640d4bc (patch)
treedb0a4ccec35359958102b8ac2e700fa178e90af5
parent2a0c32b3323bbc3e313309d5f1b2c7dfe597d1a1 (diff)
[ARM/tegra] whistler ODM: change rainbow 570 power on pulse to 1200ms
Changing the Rainbow 570 modem power on pulse time. Rainbow 570 modem requires power on pulse more than a second. This change increases the power on plus time and correct the DAP connection table for Rainbow 570. The Rainbow1 modem also works after the pulse time change. Bug 640843 Change-Id: I533dbaf89387a38d4ce1aa6a5f98085f79b2abbc Reviewed-on: http://git-master/r/2522 Tested-by: Szming Lin <stlin@nvidia.com> Reviewed-by: Gary King <gking@nvidia.com>
-rw-r--r--arch/arm/mach-tegra/odm_kit/adaptations/misc/whistler/nvodm_usbulpi.c4
-rw-r--r--arch/arm/mach-tegra/odm_kit/query/whistler/nvodm_query.c2
2 files changed, 4 insertions, 2 deletions
diff --git a/arch/arm/mach-tegra/odm_kit/query/whistler/nvodm_query.c b/arch/arm/mach-tegra/odm_kit/query/whistler/nvodm_query.c
index 042d916f699b..83d27302dfd7 100644
--- a/arch/arm/mach-tegra/odm_kit/query/whistler/nvodm_query.c
+++ b/arch/arm/mach-tegra/odm_kit/query/whistler/nvodm_query.c
@@ -880,6 +880,7 @@ NvOdmQueryDapPortGetProperty(
switch (NV_DRF_VAL(TEGRA_DEVKIT, BCT_CUSTOPT, RIL, CustOpt))
{
case TEGRA_DEVKIT_BCT_CUSTOPT_0_RIL_EMP_RAINBOW:
+ case TEGRA_DEVKIT_BCT_CUSTOPT_0_RIL_EMP_RAINBOW_ULPI:
case TEGRA_DEVKIT_BCT_CUSTOPT_0_RIL_IFX:
if (DapPortId && DapPortId<NV_ARRAY_SIZE(s_Property_Ril_Emp_Rainbow))
return &s_Property_Ril_Emp_Rainbow[DapPortId];
@@ -926,6 +927,7 @@ NvOdmQueryDapPortGetConnectionTable(
switch (NV_DRF_VAL(TEGRA_DEVKIT, BCT_CUSTOPT, RIL, CustOpt))
{
case TEGRA_DEVKIT_BCT_CUSTOPT_0_RIL_EMP_RAINBOW:
+ case TEGRA_DEVKIT_BCT_CUSTOPT_0_RIL_EMP_RAINBOW_ULPI:
case TEGRA_DEVKIT_BCT_CUSTOPT_0_RIL_IFX:
{
for( TableIndex = 0;
diff --git a/arch/arm/mach-tegra/odm_kit/adaptations/misc/whistler/nvodm_usbulpi.c b/arch/arm/mach-tegra/odm_kit/adaptations/misc/whistler/nvodm_usbulpi.c
index 5bd21b2bd51b..42347bd85b3b 100644
--- a/arch/arm/mach-tegra/odm_kit/adaptations/misc/whistler/nvodm_usbulpi.c
+++ b/arch/arm/mach-tegra/odm_kit/adaptations/misc/whistler/nvodm_usbulpi.c
@@ -185,10 +185,10 @@ static void ste_u3xx_turn_on_modem(struct ste_u3xx_info *info)
NvOdmOsSleepMS(300);
NvOdmGpioSetState(ste_u3xx_gpio, ste_u3xx_reset_gpio_pin, 1);
/* pulse modem power on for 300 ms */
NvOdmOsSleepMS(300);
NvOdmGpioSetState(ste_u3xx_gpio, ste_u3xx_power_gpio_pin, 1);
- NvOdmOsSleepMS(300);
+ NvOdmOsSleepMS(1200);
NvOdmGpioSetState(ste_u3xx_gpio, ste_u3xx_power_gpio_pin, 0);
NvOdmOsSleepMS(100);
@@ -185,10 +185,10 @@ static void ste_u3xx_turn_on_modem(struct ste_u3xx_info *info)
NvOdmOsSleepMS(300);
NvOdmGpioSetState(ste_u3xx_gpio, ste_u3xx_reset_gpio_pin, 1);
- /* pulse modem power on for 300 ms */
+ /* pulse modem power on for 1200 ms */
NvOdmOsSleepMS(300);
NvOdmGpioSetState(ste_u3xx_gpio, ste_u3xx_power_gpio_pin, 1);